changeset 17139:37acf21ce6f6

(isearch-yank): Handle case when CHUNK is `x-sel'.
author Karl Heuer <kwzh@gnu.org>
date Sat, 08 Mar 1997 19:08:39 +0000
parents b29d903ca993
children a6f8fb00d93e
files lisp/isearch.el
diffstat 1 files changed, 3 insertions(+), 1 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/isearch.el	Wed Mar 05 10:52:03 1997 +0000
+++ b/lisp/isearch.el	Sat Mar 08 19:08:39 1997 +0000
@@ -891,10 +891,12 @@
 
 (defun isearch-yank (chunk)
   ;; Helper for isearch-yank-word and isearch-yank-line
   ;; CHUNK should be word, line or kill.
   (let ((string (cond
                  ((eq chunk 'kill)
                   (current-kill 0))
+                 ((eq chunk 'x-sel)
+                  (x-get-selection))
                  (t
 		  (save-excursion
 		    (and (not isearch-forward) isearch-other-end
@@ -891,10 +891,12 @@
 (defun isearch-yank (chunk)
   ;; Helper for isearch-yank-word and isearch-yank-line
-  ;; CHUNK should be word, line or kill.
+  ;; CHUNK should be word, line, kill, or x-sel.
   (let ((string (cond
                  ((eq chunk 'kill)